@@ -87,10 +87,12 @@ class BaseAccessToken(object):
 
         # submit auth form data
         response = requests.post(action, data, cookies=self.cookies, headers=self.headers)
+        print response.content.decode('windows-1251')
+
         self.cookies = response.cookies
 
         log.debug('Response auth dict: %s' % response.__dict__)
-        log.debug('Response auth location: %s' % response.headers['location'])
+        log.debug('Response auth location: %s' % response.headers.get('location'))
 
         return response
 
